module Core.Types where

import qualified Data.Text                      as T
import qualified Data.Text.Lazy                 as LT
import           Data.ByteString as B
import           Data.Text
import           Database.SQLite.Simple         (ToRow)
import           Database.SQLite.Simple.FromRow (FromRow)
import           GHC.Generics                   (Generic)
import           Numeric.Natural                (Natural)
import           Text.Blaze.Html
import           Web.Scotty                     (ActionM, ScottyM)

type PurrApp    a = ScottyM a
type PurrAction a = ActionM a
type Random     a = IO a

newtype Password = Password' String
  deriving (Eq, Ord)

newtype UserSecret = UserSecret' String
  deriving (Eq, Ord)

newtype GenLink = GenLink' String
  deriving (Eq, Ord)

data SecretEntry = SecretEntry
  { link     :: T.Text
  , secret   :: T.Text
  , nonce    :: B.ByteString
  , date     :: Integer
  , life     :: Integer
  , views    :: Integer
  , maxViews :: Integer
  } deriving (Show, Generic)

data Secret = Password | UserSecret
    deriving (Show, Generic)

instance Show GenLink where
  show (GenLink' a) = a

instance Show Password where
  show (Password' a) = a

instance Show UserSecret where
  show (UserSecret' a) = a

instance ToMarkup Password where
  toMarkup = toMarkup . show

instance ToMarkup UserSecret where
  toMarkup = toMarkup . show

instance ToMarkup Secret where
  toMarkup = toMarkup . show

instance FromRow  SecretEntry where
instance ToRow    SecretEntry where
